.. _synthetic_data_metrics:

Synthetic Data Metrics
======================

See the `SDMetrics library <https://docs.sdv.dev/sdmetrics/>`__ for more information about the different metrics available for synthetic data.
